a named vector with mapping from cell type phrase to CURIE for CL.owl of 2025-12-17
Source:R/data.R
cn2tag.Rda named vector with mapping from cell type phrase to CURIE for CL.owl of 2025-12-17
Usage
data(cn2tag)Examples
data("cn2tag", package="ontoProc2")
cn2tag["Kupffer cell"]
#> Kupffer cell
#> "CL:0000091"