Skip to contents

a named vector with values rdfs labels in NCI thesaurus, and names the corresponding formal ontology tags

Usage

data(ncit_map)

Format

named character vector

Note

creation is detailed in unexported function makeBundledMaps

Examples

data("ncit_map", package = "ontoProc2")
head(ncit_map)
#>                    IAO:0000115                        NCIT:A1 
#>                   "definition"              "Role_Has_Domain" 
#>                       NCIT:A10                       NCIT:A11 
#>              "Has_CDRH_Parent"             "Has_NICHD_Parent" 
#>                       NCIT:A12                       NCIT:A13 
#>             "Has_Data_Element" "Related_To_Genetic_Biomarker"