retrieve and cache all filenames of Semantic SQL ontologies available, checking for updated content relative to cache via ETag
Source:R/bbop_sqlite_db_gz.R
bbop_sqlite_db_gz.Rdretrieve and cache all filenames of Semantic SQL ontologies available, checking for updated content relative to cache via ETag
Usage
bbop_sqlite_db_gz(
url = "https://s3.amazonaws.com/bbop-sqlite",
bfc = BiocFileCache::BiocFileCache(),
rname = "bbop_sqlite_listing",
timeout_connect = 5,
timeout_total = 15
)Note
There is no real etag discipline for the metadata, so full metadata content is extracted on each call, digested, and compared to digest in cache. Cache is updated when there is a discrepancy, except there is a guard against rewriting cache with corrupted or zero-length data at endpoint. Note this code was negotiated at length with claude.ai Sonnet 4.6.