a named vector with values rdfs labels in NCI thesaurus, and names the corresponding formal ontology tags
Source:R/data.R
ncit_map.Rda named vector with values rdfs labels in NCI thesaurus, and names the corresponding formal ontology tags
Usage
data(ncit_map)