a named vector with values rdfs labels in NCI thesaurus, and names the corresponding formal ontology tags
Source:R/data.R
ncit_map.Rda named vector with values rdfs labels in NCI thesaurus, and names the corresponding formal ontology tags
Usage
data(ncit_map)Examples
data("ncit_map", package="ontoProc2")
ncit_map["EFO:1000899"]
#> EFO:1000899
#> "diastolic heart failure"