Opens a connection, evaluates an expression with conn bound to the
open SemsqlConn, then closes the connection even if an error occurs.
Analogous to Python's context manager (with statement).
Examples
if (FALSE) { # \dontrun{
result <- with_connection("cl.db", {
get_ancestors(conn, "CL:0000540")
})
} # }